#import <Foundation/Foundation.h>
#import "AsReaderP252BProtocol.h"
#import "AsReaderP252BModule.h"
#import "AsReaderP252BDevice.h"

@protocol AsReaderDelegate;

@interface AsReaderP252B : AsReaderP252BDevice

@property (nonatomic, assign) int minQ;
@property (nonatomic, assign) int maxQ;
@property (nonatomic, assign) int qValue;
@property (nonatomic, assign) int idleTime;     //0~65535 (10ms)
@property (nonatomic, assign) int powerGain;
@property (nonatomic, assign) int sleepTime;    //0~1800(s)
@property (nonatomic, assign) int autoOffTime;  //0~1800(s)
@property (nonatomic, assign) int operationTime;//0~1800(s)
@property (nonatomic, assign) int inventoryTime;//0~65535 (10ms)
@property (nonatomic, assign) int linkProfileValue;
@property (nonatomic, assign) BOOL rssiMode;
@property (nonatomic, assign) BOOL continuousMode;
@property (nonatomic, strong) NSString *serialNumber;
@property (nonatomic, strong) NSString *accessPassword;
@property (nonatomic, assign) AsReaderP252BBuzzerState buzzer;
@property (nonatomic, assign) AsReaderP252BSessionFlag sessionFlag;
@property (nonatomic, assign) AsReaderP252BSessionType inventorySession;

- (void)setDelegate:(id<AsReaderP252BDelegate>)delegate;
- (int)batteryStatus;
- (NSString *)regionName;
- (NSString *)serialNumber;
- (NSString *)rFModuleVersion;
- (NSString *)hardwareVersion;
- (NSString *)firmwareVersion;
- (NSString *)getMessageWithAsReaderP252BResultCode:(AsReaderP252BResultCode)code;
- (AsReaderP252BCommandType)getAction;
- (AsReaderP252BMinMaxValue)powerGainRange;
- (AsReaderP252BResultCode)inventory;
- (AsReaderP252BResultCode)inventoryHumidityTag;
- (AsReaderP252BResultCode)inventoryTemperatureTagWithType:(AsReaderP252BTemperatureTagType)type;
- (AsReaderP252BResultCode)stop;
- (AsReaderP252BResultCode)stopSync;
- (AsReaderP252BResultCode)readMemory:(AsReaderP252BMemoryBank)bank offset:(int)offset length:(int)length;
- (AsReaderP252BResultCode)writeMemory:(AsReaderP252BMemoryBank)bank offset:(int)offset value:(NSString *)value;
- (AsReaderP252BResultCode)lock:(AsReaderP252BLockParam *)param;
- (AsReaderP252BResultCode)unlock:(AsReaderP252BLockParam *)param;
- (AsReaderP252BResultCode)permaLock:(AsReaderP252BLockParam *)param;
- (AsReaderP252BResultCode)kill:(NSString *)killPassword;
- (AsReaderP252BResultCode)defaultParameter;
- (AsReaderP252BResultCode)saveParameter;
//Barcode
- (AsReaderP252BResultCode)startDecode;
- (AsReaderP252BResultCode)setBarcodeTimeOut:(int)barcodeTimeOut;
- (int)getBarcodeTimeOut;
//EpcMask
- (int)epcMaskCount;
- (AsReaderP252BResultCode)addEpcMask:(int) offset length:(int)length mask:(NSString *)mask;
- (AsReaderP252BResultCode)addEpcMask:(AsReaderP252BSelectMaskEPCParam *)mask;
- (AsReaderP252BSelectMaskEPCParam *)getEpcMask:(int)index;
- (AsReaderP252BResultCode)clearEpcMask;
//LBT
- (void)setFrequencyAutomatic:(BOOL)isAutomatic;
- (BOOL)getFrequencyAutomatic;
- (void)setFrequency:(NSArray *)table;
- (NSArray *)getFrequency;

- (void)setScanMode:(AsReaderP252BScanMode)scanMode;
- (AsReaderP252BScanMode)getScanMode;

- (NSMutableArray *)getBaudRateList;
- (AsReaderP252BResultCode)setBaudRate:(int)baudRate;
- (int)getBaudRate;
+ (NSString *)getSDKVersion;
@end
